@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for Fedora 15's 2.6.43 kernel.
+# This is a kernel build script for Fedora 18's 3.7 kernel.
 #
 
 die () {
@@ -8,21 +8,21 @@ die () {
     exit 1
 }
 
-yum -y install wget rpm-build make gcc redhat-rpm-config xmlto asciidoc gnupg elfutils-devel zlib-devel binutils-devel newt-devel python-devel perl-ExtUtils-Embed pciutils-devel hmaccalc
+yum -y install wget rpm-build make gcc patch redhat-rpm-config xmlto asciidoc gnupg elfutils-devel zlib-devel binutils-devel newt-devel python-devel perl-ExtUtils-Embed pciutils-devel hmaccalc bison net-tools audit-libs-devel pesign
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.43.8-1.fc15.src.rpm ]
+if [ ! -r kernel-3.7.6-201.fc18.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/fedora/updates/15/SRPMS/kernel-2.6.43.8-1.fc15.src.rpm || die "Can't download source package."
+    wget http://ftp.riken.jp/Linux/fedora/updates/18/SRPMS/kernel-3.6.11-5.fc17.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-2.6.43.8-1.fc15.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-2.6.43.8-1.fc15.src.rpm || die "Can't install source package."
+rpm --checksig kernel-3.7.6-201.fc18.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-3.7.6-201.fc18.src.rpm || die "Can't install source package."
 
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.3-20130117.tar.gz ]
+if [ ! -r ccs-patch-1.8.3-20130214.tar.gz ]
 then
-    wget -O ccs-patch-1.8.3-20130117.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20130117.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.3-20130214.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20130214.tar.gz' || die "Can't download patch."
 fi
 
 cd /root/rpmbuild/SPECS/ || die "Can't chdir to /root/rpmbuild/SPECS/ ."
@@ -30,7 +30,7 @@ cp -p kernel.spec ccs-kernel.spec || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
 --- ccs-kernel.spec
 +++ ccs-kernel.spec
-@@ -18,7 +18,7 @@
+@@ -31,7 +31,7 @@
  #
  # (Uncomment the '#' and both spaces below to set the buildid.)
  #
@@ -39,7 +39,7 @@ patch << "EOF" || die "Can't patch spec file."
  ###################################################################
  
  # The buildid can also be specified on the rpmbuild command line
-@@ -405,6 +405,11 @@
+@@ -460,6 +460,11 @@
  # to versions below the minimum
  #
  
@@ -51,16 +51,16 @@ patch << "EOF" || die "Can't patch spec file."
  #
  # First the general kernel 2.6 required versions as per
  # Documentation/Changes
-@@ -464,7 +469,7 @@
+@@ -515,7 +520,7 @@
  AutoProv: yes\
  %{nil}
  
 -Name: kernel%{?variant}
 +Name: ccs-kernel%{?variant}
  Group: System Environment/Kernel
- License: GPLv2
+ License: GPLv2 and Redistributable, no modification permitted
  URL: http://www.kernel.org/
-@@ -827,7 +832,7 @@
+@@ -972,7 +977,7 @@
  AutoReqProv: no\
  Requires(pre): /usr/bin/find\
  Requires: perl\
@@ -69,18 +69,27 @@ patch << "EOF" || die "Can't patch spec file."
  This package provides kernel headers and makefiles sufficient to build modules\
  against the %{?2:%{2} }kernel package.\
  %{nil}
-@@ -1305,6 +1310,10 @@
+@@ -992,7 +997,7 @@
+ Provides: kernel-modules-extra-uname-r = %{KVERREL}%{?1:.%{1}}\
+ Requires: kernel-uname-r = %{KVERREL}%{?1:.%{1}}\
+ AutoReqProv: no\
+-%description -n kernel%{?variant}%{?1:-%{1}}-modules-extra\
++%description -n ccs-kernel%{?variant}%{?1:-%{1}}-modules-extra\
+ This package provides less commonly used kernel modules for the %{?2:%{2} }kernel package.\
+ %{nil}
+ 
+@@ -1511,6 +1516,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.3-20130117.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.43-fedora-15.diff
++tar -zxf %_sourcedir/ccs-patch-1.8.3-20130214.tar.gz
++patch -sp1 < patches/ccs-patch-3.7-fedora-18.diff
 +
  %endif
  
  # Any further pre-build tree manipulations happen here.
-@@ -1333,6 +1342,18 @@
+@@ -1540,6 +1549,18 @@
  for i in *.config
  do
    mv $i .config
